hstrat.hstrat.HereditaryStratumOrderedStoreDict
===============================================

.. currentmodule:: hstrat.hstrat

.. autoclass:: HereditaryStratumOrderedStoreDict

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~HereditaryStratumOrderedStoreDict.Clone
      ~HereditaryStratumOrderedStoreDict.DelRanks
      ~HereditaryStratumOrderedStoreDict.DepositStratum
      ~HereditaryStratumOrderedStoreDict.GetColumnIndexOfRank
      ~HereditaryStratumOrderedStoreDict.GetNumStrataRetained
      ~HereditaryStratumOrderedStoreDict.GetRankAtColumnIndex
      ~HereditaryStratumOrderedStoreDict.GetRetainedRanks
      ~HereditaryStratumOrderedStoreDict.GetStratumAtColumnIndex
      ~HereditaryStratumOrderedStoreDict.IterRankDifferentia
      ~HereditaryStratumOrderedStoreDict.__init__
   
   

   
   
   